@@ -4,14 +4,14 @@ import asyncio
 import contextlib
 import logging
 import struct
-from collections.abc import Callable, Iterable
+from collections.abc import Awaitable, Callable, Iterable
 from dataclasses import replace
 from typing import Any, TypeVar, cast
 
 import async_timeout
 from bleak.backends.device import BLEDevice
 from bleak.backends.scanner import AdvertisementData
-from bleak.exc import BleakDBusError
+from bleak.exc import BleakDBusError, BleakError
 from bleak_retry_connector import BLEAK_RETRY_EXCEPTIONS, BleakNotFoundError, get_device
 
 from .const import (
@@ -19,6 +19,7 @@ from .const import (
     HAP_ENCRYPTED_FIRST_BYTE,
     HAP_FIRST_BYTE,
     YALE_MFR_ID,
+    AuthState,
     BatteryState,
     ConnectionInfo,
     DoorStatus,
@@ -27,7 +28,14 @@ from .const import (
     LockStatus,
 )
 from .lock import Lock
-from .session import AuthError, DisconnectedError, NoAdvertisementError, ResponseError
+from .session import (
+    AuthError,
+    BluetoothError,
+    DisconnectedError,
+    NoAdvertisementError,
+    ResponseError,
+    YaleXSBLEError,
+)
 from .util import is_disconnected_error, local_name_is_unique
 
 _LOGGER = logging.getLogger(__name__)
@@ -99,6 +107,7 @@ def retry_bluetooth_connection_error(func: WrapFuncType) -> WrapFuncType:
             try:
                 return await func(self, *args, **kwargs)
             except AuthError:
+                self._update_any_state([AuthState(successful=False)])
                 raise
             except BleakNotFoundError:
                 # The lock cannot be found so there is no
@@ -189,7 +198,6 @@ class PushLock:
         self._ble_device = ble_device
         self._operation_lock = asyncio.Lock()
         self._running = False
-        self._battery_state: BatteryState | None = None
         self._callbacks: list[
             Callable[[LockState, LockInfo, ConnectionInfo], None]
         ] = []
@@ -202,6 +210,7 @@ class PushLock:
         self._disconnect_timer: asyncio.TimerHandle | None = None
         self._idle_disconnect_delay = idle_disconnect_delay
         self._first_update_future: asyncio.Future[None] | None = None
+        self._background_tasks: set[asyncio.Task[None]] = set()
 
     @property
     def local_name(self) -> str | None:
@@ -237,6 +246,11 @@ class PushLock:
         """Return the current battery state."""
         return self._lock_state.battery if self._lock_state else None
 
+    @property
+    def auth(self) -> AuthState | None:
+        """Return the current auth state."""
+        return self._lock_state.auth if self._lock_state else None
+
     @property
     def lock_state(self) -> LockState | None:
         """Return the current lock state."""
@@ -330,7 +344,7 @@ class PushLock:
             self._reset_disconnect_timer()
             return
         self._cancel_disconnect_timer()
-        asyncio.create_task(self._execute_timed_disconnect())
+        self.background_task(self._execute_timed_disconnect())
 
     def _cancel_disconnect_timer(self) -> None:
         """Cancel disconnect timer."""
@@ -354,7 +368,7 @@ class PushLock:
                 return
             client = self._client
             self._client = None
-            if client and client.is_connected:
+            if client:
                 _LOGGER.debug("%s: Disconnecting", self.name)
                 await client.disconnect()
                 _LOGGER.debug("%s: Disconnect completed", self.name)
@@ -438,15 +452,17 @@ class PushLock:
         self._update_any_state(states)
 
     def _update_any_state(
-        self, states: Iterable[LockStatus | DoorStatus | BatteryState]
+        self, states: Iterable[LockStatus | DoorStatus | BatteryState | AuthState]
     ) -> None:
         _LOGGER.debug("%s: State changed: %s", self.name, states)
         lock_state = self._lock_state or LockState(
-            self.lock_status, self.door_status, self.battery
+            self.lock_status, self.door_status, self.battery, self.auth
         )
         original_lock_status = lock_state.lock
         for state in states:
-            if isinstance(state, LockStatus):
+            if isinstance(state, AuthState):
+                lock_state = replace(lock_state, auth=state)
+            elif isinstance(state, LockStatus):
                 lock_state = replace(lock_state, lock=state)
             elif isinstance(state, DoorStatus):
                 lock_state = replace(lock_state, door=state)
@@ -464,6 +480,7 @@ class PushLock:
 
         if (
             original_lock_status != lock_state.lock
+            and (not lock_state.auth or lock_state.auth.successful)
             and original_lock_status != LockStatus.UNKNOWN
         ):
             self._schedule_resync()
@@ -498,8 +515,10 @@ class PushLock:
             if not self._lock_info:
                 self._lock_info = await lock.lock_info()
             state = await lock.status()
-            self._battery_state = await lock.battery()
-            state = replace(state, battery=self._battery_state)
+            battery_state = await lock.battery()
+            state = replace(
+                state, battery=battery_state, auth=AuthState(successful=True)
+            )
         except asyncio.CancelledError:
             _LOGGER.debug(
                 "%s: In-progress update canceled due "
@@ -631,10 +650,16 @@ class PushLock:
         def _cancel() -> None:
             self._running = False
             self._cancel_resync()
-            asyncio.create_task(self._execute_forced_disconnect())
+            self.background_task(self._execute_forced_disconnect())
 
         return _cancel
 
+    def background_task(self, fut: Awaitable[Any]) -> None:
+        """Execute a background task."""
+        task = asyncio.create_task(fut)
+        self._background_tasks.add(task)
+        task.add_done_callback(self._background_tasks.remove)
+
     async def wait_for_first_update(self, timeout: float) -> None:
         """Wait for the first update."""
         if not self._running:
@@ -756,9 +781,16 @@ class PushLock:
             except asyncio.TimeoutError as ex:
                 self._set_update_state(ex)
                 _LOGGER.exception("%s: Timed out updating", self.name)
+            except BleakError as ex:
+                wrapped_bleak_exc = BluetoothError(str(ex))
+                wrapped_bleak_exc.__cause__ = ex
+                self._set_update_state(wrapped_bleak_exc)
+                _LOGGER.exception("%s: Bluetooth error updating", self.name)
             except Exception as ex:  # pylint: disable=broad-except
-                self._set_update_state(ex)
-                _LOGGER.exception("%s: Error updating", self.name)
+                wrapped_exc = YaleXSBLEError(str(ex))
+                wrapped_exc.__cause__ = ex
+                self._set_update_state(wrapped_exc)
+                _LOGGER.exception("%s: Unknown error updating", self.name)
 
 
 def get_homekit_state_num(data: bytes) -> int:
